@@ -5,6 +5,7 @@ from groundx.apis.tags.documents_api import DocumentsApi
 from groundx.apis.tags.search_api import SearchApi
 from groundx.apis.tags.projects_api import ProjectsApi
 from groundx.apis.tags.buckets_api import BucketsApi
+from groundx.apis.tags.test_api import TestApi
 
 TagToApi = typing_extensions.TypedDict(
     'TagToApi',
@@ -13,6 +14,7 @@ TagToApi = typing_extensions.TypedDict(
         TagValues.SEARCH: SearchApi,
         TagValues.PROJECTS: ProjectsApi,
         TagValues.BUCKETS: BucketsApi,
+        TagValues.TEST: TestApi,
     }
 )
 
@@ -22,5 +24,6 @@ tag_to_api = TagToApi(
         TagValues.SEARCH: SearchApi,
         TagValues.PROJECTS: ProjectsApi,
         TagValues.BUCKETS: BucketsApi,
+        TagValues.TEST: TestApi,
     }
 )
